==> open-xchange-core_7.6.3.orig.tar.bz2: open-xchange-core-7.6.3/com.openexchange.frontend.uwa/src/com/openexchange/frontend/uwa/osgi/UWAWidgetActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.frontend.uwa.osgi;

import java.util.Arrays;
import java.util.Collection;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.frontend.uwa.UWAWidgetServiceFactory;
import com.openexchange.frontend.uwa.internal.UWAWidgetServiceFactoryImpl;
import com.openexchange.frontend.uwa.internal.groupware.CreatePositionsTable;
import com.openexchange.frontend.uwa.internal.groupware.CreatePositionsTableTask;
import com.openexchange.frontend.uwa.internal.groupware.CreateWidgetTable;
import com.openexchange.frontend.uwa.internal.groupware.CreateWidgetTableTask;
import com.openexchange.groupware.update.UpdateTask;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.id.IDGeneratorService;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link UWAWidgetActivator}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class UWAWidgetActivator extends HousekeepingActivator {

    private static final Class[] NEEDED = new Class[]{DatabaseService.class, IDGeneratorService.class, ConfigurationService.class, ConfigViewFactory.class};

    @Override
    protected Class<?>[] getNeededServices() {
        return NEEDED;
    }

    @Override
    protected void startBundle() throws Exception {
        DatabaseService dbService = getService(DatabaseService.class);
        IDGeneratorService idGenService = getService(IDGeneratorService.class);
        ConfigurationService configService = getService(ConfigurationService.class);
        ConfigViewFactory configViewsService = getService(ConfigViewFactory.class);

        UWAWidgetServiceFactoryImpl factory = new UWAWidgetServiceFactoryImpl(dbService, configViewsService, configService, idGenService);

        registerService(UWAWidgetServiceFactory.class, factory);


        // Database

        CreatePositionsTable positionsTable = new CreatePositionsTable();
        registerService(CreateTableService.class, positionsTable);

        CreateWidgetTable widgetTable = new CreateWidgetTable();
        registerService(CreateTableService.class, widgetTable);

        final CreatePositionsTableTask updateTask1 = new CreatePositionsTableTask(dbService);
        final CreateWidgetTableTask updateTask2 = new CreateWidgetTableTask(dbService);

        registerService(UpdateTaskProviderService.class, new UpdateTaskProviderService() {

            @Override
            public Collection<? extends UpdateTask> getUpdateTasks() {
                return Arrays.asList(updateTask1, updateTask2);
            }

        });

    }

}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.frontend.uwa/src/com/openexchange/frontend/uwa/osgi/UWAWidgetActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.frontend.uwa.osgi;

import java.util.Arrays;
import java.util.Collection;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.frontend.uwa.UWAWidgetServiceFactory;
import com.openexchange.frontend.uwa.internal.UWAWidgetServiceFactoryImpl;
import com.openexchange.frontend.uwa.internal.groupware.CreatePositionsTable;
import com.openexchange.frontend.uwa.internal.groupware.CreatePositionsTableTask;
import com.openexchange.frontend.uwa.internal.groupware.CreateWidgetTable;
import com.openexchange.frontend.uwa.internal.groupware.CreateWidgetTableTask;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskV2;
import com.openexchange.id.IDGeneratorService;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link UWAWidgetActivator}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class UWAWidgetActivator extends HousekeepingActivator {

    private static final Class[] NEEDED = new Class[]{DatabaseService.class, IDGeneratorService.class, ConfigurationService.class, ConfigViewFactory.class};

    @Override
    protected Class<?>[] getNeededServices() {
        return NEEDED;
    }

    @Override
    protected void startBundle() throws Exception {
        DatabaseService dbService = getService(DatabaseService.class);
        IDGeneratorService idGenService = getService(IDGeneratorService.class);
        ConfigurationService configService = getService(ConfigurationService.class);
        ConfigViewFactory configViewsService = getService(ConfigViewFactory.class);

        UWAWidgetServiceFactoryImpl factory = new UWAWidgetServiceFactoryImpl(dbService, configViewsService, configService, idGenService);

        registerService(UWAWidgetServiceFactory.class, factory);


        // Database

        CreatePositionsTable positionsTable = new CreatePositionsTable();
        registerService(CreateTableService.class, positionsTable);

        CreateWidgetTable widgetTable = new CreateWidgetTable();
        registerService(CreateTableService.class, widgetTable);

        final CreatePositionsTableTask updateTask1 = new CreatePositionsTableTask(dbService);
        final CreateWidgetTableTask updateTask2 = new CreateWidgetTableTask(dbService);

        registerService(UpdateTaskProviderService.class, new UpdateTaskProviderService() {

            @Override
            public Collection<? extends UpdateTaskV2> getUpdateTasks() {
                return Arrays.asList(updateTask1, updateTask2);
            }

        });

    }

}
